==> benno-web-2.8.4.tgz: srv/benno/bennoweb/htdocs/pre_init.php <==
<?php
/*
 * Benno MailArchiv
 *
 * Copyright  2008-2012 LWsystems GmbH & Co. KG
 *
 * http://www.lw-systems.de/
 * http://www.benno-mailarchiv.de/
 *
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License version 3
 * as published by the Free Software Foundation.
 *
 * Binary versions of this file provided by LWsystems to you as
 * well as other copyrighted, protected or trademarked materials like
 * logos, graphics, fonts, specific documentations and configurations,
 * cryptographic keys etc. are subject to a license agreement between
 * you and LWsystems.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You can find a copy of the GNU Affero General Public License at
 * this URI:
 * http://www.gnu.org/licenses/agpl-3.0.html
 * If not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA  02111-1307  USA
 */

/** $Id: $
 *
 * Copyright (c) 2005 Martin Werthmoeller <mw@lw-systems.de>
 *
 */
/**
 * @package pre_init
 */
/**
 * 
 * pre_init.php will be called before the session is initiated.
 *
 * Include here all classes that will be stored at a session.
 *
 */
// add lib/model to include_path
// $include_path = ini_get('include_path');
// ini_set('include_path',$include_path.':lib');

// ACCESS CONSTANTS
define('BNO_AUTH',    0b00000010);   //   2 User authenticated
define('BNO_USER',    0b00000100);   //   4 userpanel (change password)
define('BNO_SYSINFO', 0b00001000);   //   8 Show system information
define('BNO_SYSDATA', 0b00010000);   //  16 SYSDATA container
define('BNO_ADMIN',   0b00100000);   //  32 admingui (change address, role)
define('BNO_STATS',   0b01000000);   //  64 statistics
define('BNO_SITEADM', 0b10000000);   // 128 admingui (change container)

require_once 'model/User.php';
require_once 'model/Backend.php';
require_once 'model/Query.php';
require_once 'model/StoredQuery.php';
require_once 'model/QueryResult.php';
require_once 'model/EMail.php';
require_once 'model/Filter.php';
require_once 'model/Audit.php';
require_once 'model/aError.php';
include_once 'model/PermaId.php';

?>

==> benno-web-2.8.5.tgz: srv/benno/bennoweb/htdocs/pre_init.php <==
<?php
/*
 * Benno MailArchiv
 *
 * Copyright  2008-2012 LWsystems GmbH & Co. KG
 *
 * http://www.lw-systems.de/
 * http://www.benno-mailarchiv.de/
 *
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License version 3
 * as published by the Free Software Foundation.
 *
 * Binary versions of this file provided by LWsystems to you as
 * well as other copyrighted, protected or trademarked materials like
 * logos, graphics, fonts, specific documentations and configurations,
 * cryptographic keys etc. are subject to a license agreement between
 * you and LWsystems.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You can find a copy of the GNU Affero General Public License at
 * this URI:
 * http://www.gnu.org/licenses/agpl-3.0.html
 * If not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA  02111-1307  USA
 */

/** $Id: $
 *
 * Copyright (c) 2005 Martin Werthmoeller <mw@lw-systems.de>
 *
 */
/**
 * @package pre_init
 */
/**
 * 
 * pre_init.php will be called before the session is initiated.
 *
 * Include here all classes that will be stored at a session.
 *
 */
// add lib/model to include_path
// $include_path = ini_get('include_path');
// ini_set('include_path',$include_path.':lib');

// ACCESS CONSTANTS
define('BNO_AUTH',    0b00000010);   //   2 user authenticated
define('BNO_USER',    0b00000100);   //   4 edit user
define('BNO_SYSINFO', 0b00001000);   //   8 Show system information
define('BNO_SYSDATA', 0b00010000);   //  16 SYSDATA container
define('BNO_ADMIN',   0b00100000);   //  32 admingui (change address, role)
define('BNO_STATS',   0b01000000);   //  64 statistics
define('BNO_SITEADM', 0b10000000);   // 128 admingui (change container)

require_once 'model/User.php';
require_once 'model/Backend.php';
require_once 'model/Query.php';
require_once 'model/StoredQuery.php';
require_once 'model/QueryResult.php';
require_once 'model/EMail.php';
require_once 'model/Filter.php';
require_once 'model/Audit.php';
require_once 'model/aError.php';
include_once 'model/PermaId.php';

?>
